#[non_exhaustive]pub enum AtspiError {
Show 24 variants
Conversion(&'static str),
CacheVariantMismatch,
MemberMatch(String),
InterfaceMatch(String),
KindMatch(String),
InterfaceNotAvailable(&'static str),
SignatureMatch(String),
UnknownInterface,
MissingInterface,
MissingMember,
MissingPath,
UnknownRole(u32),
MissingName,
UnknownSignal,
Owned(String),
NullRef(&'static str),
Zbus(String),
ZBusNames(Error),
Zvariant(Error),
ParseError(&'static str),
PathConversionError(ObjectPathConversionError),
IO(Error),
IntConversionError(TryFromIntError),
Infallible,
}Expand description
An error type that can describe atspi and std and different zbus errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Conversion(&'static str)
Converting one type into another failure
CacheVariantMismatch
When testing on either variant, we might find the we are not interested in.
MemberMatch(String)
On specific types, if the event / message member does not match the Event’s name.
InterfaceMatch(String)
On specific types, if the event / message member does not match the Event’s name.
KindMatch(String)
On specific types, if the kind (string variant) does not match the Event’s kind.
InterfaceNotAvailable(&'static str)
When an interface is not available.
SignatureMatch(String)
To indicate a match or equality test on a signal body signature failed.
UnknownInterface
When matching on an unknown interface
MissingInterface
No interface on event.
MissingMember
No member on event.
MissingPath
No path on event.
UnknownRole(u32)
When matching on an unknown role
MissingName
No name on bus.
UnknownSignal
The signal that was encountered is unknown.
Owned(String)
Other errors.
NullRef(&'static str)
Null-reference error. This is used when an ObjectRef is expected to be non-null, but it is null.
Zbus(String)
A zbus or zbus::Fdo error. variant.
ZBusNames(Error)
A zbus_names error variant
Zvariant(Error)
A zbus_names error variant
ParseError(&'static str)
Failed to parse a string into an enum variant
PathConversionError(ObjectPathConversionError)
Failed to get the ID of a path.
IO(Error)
Std i/o error variant.
IntConversionError(TryFromIntError)
Failed to convert an integer into another type of integer (usually i32 -> usize).
Infallible
An infallible error; this is just something to satisfy the compiler.